/*******************************************************************\

Module: Havoc Loops

Author: Daniel Kroening, kroening@kroening.com

\*******************************************************************/

/// \file
/// Havoc Loops

#ifndef CPROVER_GOTO_INSTRUMENT_HAVOC_LOOPS_H
#define CPROVER_GOTO_INSTRUMENT_HAVOC_LOOPS_H

class goto_modelt;

void havoc_loops(goto_modelt &);

#endif // CPROVER_GOTO_INSTRUMENT_HAVOC_LOOPS_H
